from os import name
from setuptools import setup, version
import setuptools

setup(
    name='mogaubin_distributions',
    version='0.1.0',
    description='Gaussian and Binomial distributions',
    package=['mogausbin_distributions'],
    author='Martin Oywa',
    author_email='test.email@email.com',
    zip_safe=False
)
